@@ -1,12 +1,12 @@
 package Plack::Middleware::PeriAHS::ParseRequest;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::ger;
 
 use Perinci::AccessUtil qw(insert_riap_stuffs_to_res decode_args_in_riap_req);
 use Perinci::Access::Base::Patch::PeriAHS;
@@ -134,12 +134,12 @@ sub prepare_app {
     $self->{php_clients_ua_re} //= qr(Phinci|/php|php/)i;
     $self->{deconfuse_php_clients} //= 1;
 
-    $log->tracef("Prepared PeriAHS::ParseRequest middleware: %s", $self);
+    log_trace("Prepared PeriAHS::ParseRequest middleware: %s", $self);
 }
 
 sub call {
     my ($self, $env) = @_;
-    $log->tracef("=> PeriAHS::ParseRequest middleware");
+    log_trace("=> PeriAHS::ParseRequest middleware");
 
     my $rreq = $env->{"riap.request"} //= {};
 
@@ -427,7 +427,7 @@ sub call {
     # Riap 1.2: decode base64-encoded args
     decode_args_in_riap_req($rreq);
 
-    $log->tracef("Riap request: %s", $rreq);
+    log_trace("Riap request: %s", $rreq);
 
     # expose configuration for other middlewares
     $env->{"middleware.PeriAHS.ParseRequest"} = $self;
@@ -451,7 +451,7 @@ Plack::Middleware::PeriAHS::ParseRequest - Parse Riap request from HTTP request
 
 =head1 VERSION
 
-This document describes version 0.60 of Plack::Middleware::PeriAHS::ParseRequest (from Perl distribution Perinci-Access-HTTP-Server), released on 2016-03-16.
+This document describes version 0.61 of Plack::Middleware::PeriAHS::ParseRequest (from Perl distribution Perinci-Access-HTTP-Server), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -709,7 +709,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-HTTP-Server>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-HTTP-Server>.
 
 =head1 BUGS
 
@@ -729,7 +729,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
