@@ -1,12 +1,12 @@
 package Plack::Util::PeriAHS;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::ger;
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(errpage);
@@ -42,7 +42,7 @@ sub errpage {
         ];
     }
 
-    $log->tracef("Returning error page: %s", $pres);
+    log_trace("Returning error page: %s", $pres);
     $pres;
 }
 
@@ -61,7 +61,7 @@ Plack::Util::PeriAHS - Utility routines
 
 =head1 VERSION
 
-This document describes version 0.60 of Plack::Util::PeriAHS (from Perl distribution Perinci-Access-HTTP-Server), released on 2016-03-16.
+This document describes version 0.61 of Plack::Util::PeriAHS (from Perl distribution Perinci-Access-HTTP-Server), released on 2017-07-10.
 
 =head1 FUNCTIONS
 
@@ -79,7 +79,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-HTTP-Server>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-HTTP-Server>.
 
 =head1 BUGS
 
@@ -95,7 +95,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
